# unEQ

CLI application for removing EQ from video files. Currently only supports Peace configs.

## Requirements

- FFmpeg

## Installation

`pip install uneq`

## Usage

`uneq -i [video path] -e [eq config path]`

e.g. `uneq -i "C:/Videos/video.mp4" -e "C:/Program Files/EqualizerAPO/config/peace.txt"`

## Limitations

Currently only officially supports configs generated by Peace, and is limited to handling the following filter types:

- PK (peak)
- LSC (low shelf)
- HSC (high shelf)
